@@ -20,7 +20,7 @@ $g1->circle(width=>1,height=>1,id=>'test_id');
 $g1->rect(id=>'id_2');
 $g1->rect(id=>'id_3');
 $g1->rect(id=>'id_4',x=>15,y=>150);
-$g1->anchor(-xref=>'http://www.roasp.com/tutorial/',id=>'anchor_1')
+$g1->anchor(-xref=>'http://www.roitsystems.com/tutorial/',id=>'anchor_1')
     ->text(id=>'text_1',x=>15,y=>150,stroke=>'red')->cdata('Hello, World');
 
 my $g2 = $s->group(id=>'group_2');
